@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from io import BytesIO
 
 from translate.convert import po2tmx, test_convert
@@ -7,17 +5,20 @@ from translate.misc.xml_helpers import XML_NS
 from translate.storage import tmx
 
 
-class TestPO2TMX(object):
-
-    def po2tmx(self, posource, sourcelanguage='en', targetlanguage='af',
-               comment=None):
+class TestPO2TMX:
+    def po2tmx(self, posource, sourcelanguage="en", targetlanguage="af", comment=None):
         """helper that converts po source to tmx source without requiring files"""
-        inputfile = BytesIO(posource.encode('utf-8'))
+        inputfile = BytesIO(posource.encode("utf-8"))
         outputfile = BytesIO()
         outputfile.tmxfile = tmx.tmxfile(inputfile=None, sourcelanguage=sourcelanguage)
-        po2tmx.convertpo(inputfile, outputfile, templatefile=None,
-                         sourcelanguage=sourcelanguage,
-                         targetlanguage=targetlanguage, comment=comment)
+        po2tmx.convertpo(
+            inputfile,
+            outputfile,
+            templatefile=None,
+            sourcelanguage=sourcelanguage,
+            targetlanguage=targetlanguage,
+            comment=comment,
+        )
         return outputfile.tmxfile
 
     def test_basic(self):
@@ -45,14 +46,14 @@ msgstr "Toepassings"
         print(bytes(tmx))
         assert tmx.translate("Applications") == "Toepassings"
         assert tmx.translate("bla") is None
-        xmltext = bytes(tmx).decode('utf-8')
+        xmltext = bytes(tmx).decode("utf-8")
         assert xmltext.index('creationtool="Translate Toolkit"')
-        assert xmltext.index('adminlang')
-        assert xmltext.index('creationtoolversion')
-        assert xmltext.index('datatype')
-        assert xmltext.index('o-tmf')
-        assert xmltext.index('segtype')
-        assert xmltext.index('srclang')
+        assert xmltext.index("adminlang")
+        assert xmltext.index("creationtoolversion")
+        assert xmltext.index("datatype")
+        assert xmltext.index("o-tmf")
+        assert xmltext.index("segtype")
+        assert xmltext.index("srclang")
 
     def test_sourcelanguage(self):
         minipo = 'msgid "String"\nmsgstr "String"\n'
@@ -68,7 +69,7 @@ msgstr "Toepassings"
         print("The generated xml:")
         print(bytes(tmx))
         tuv = tmx.document.findall(".//%s" % tmx.namespaced("tuv"))[1]
-        #tag[0] will be the source, we want the target tuv
+        # tag[0] will be the source, we want the target tuv
         assert tuv.get("{%s}lang" % XML_NS) == "xh"
 
     def test_multiline(self):
@@ -80,13 +81,13 @@ msgstr "Eerste deel "
         tmx = self.po2tmx(minipo)
         print("The generated xml:")
         print(bytes(tmx))
-        assert tmx.translate('First part and extra') == 'Eerste deel en ekstra'
+        assert tmx.translate("First part and extra") == "Eerste deel en ekstra"
 
     def test_escapednewlines(self):
         """Test the escaping of newlines"""
-        minipo = r'''msgid "First line\nSecond line"
+        minipo = r"""msgid "First line\nSecond line"
 msgstr "Eerste lyn\nTweede lyn"
-'''
+"""
         tmx = self.po2tmx(minipo)
         print("The generated xml:")
         print(bytes(tmx))
@@ -94,31 +95,33 @@ msgstr "Eerste lyn\nTweede lyn"
 
     def test_escapedtabs(self):
         """Test the escaping of tabs"""
-        minipo = r'''msgid "First column\tSecond column"
+        minipo = r"""msgid "First column\tSecond column"
 msgstr "Eerste kolom\tTweede kolom"
-'''
+"""
         tmx = self.po2tmx(minipo)
         print("The generated xml:")
         print(bytes(tmx))
-        assert tmx.translate("First column\tSecond column") == "Eerste kolom\tTweede kolom"
+        assert (
+            tmx.translate("First column\tSecond column") == "Eerste kolom\tTweede kolom"
+        )
 
     def test_escapedquotes(self):
         """Test the escaping of quotes (and slash)"""
-        minipo = r'''msgid "Hello \"Everyone\""
+        minipo = r"""msgid "Hello \"Everyone\""
 msgstr "Good day \"All\""
 
 msgid "Use \\\"."
 msgstr "Gebruik \\\"."
-'''
+"""
         tmx = self.po2tmx(minipo)
         print("The generated xml:")
         print(bytes(tmx))
         assert tmx.translate('Hello "Everyone"') == 'Good day "All"'
-        assert tmx.translate(r'Use \".') == r'Gebruik \".'
+        assert tmx.translate(r"Use \".") == r"Gebruik \"."
 
     def test_exclusions(self):
         """Test that empty and fuzzy messages are excluded"""
-        minipo = r'''#, fuzzy
+        minipo = r"""#, fuzzy
 msgid "One"
 msgstr "Een"
 
@@ -127,7 +130,7 @@ msgstr ""
 
 msgid ""
 msgstr "Drie"
-'''
+"""
         tmx = self.po2tmx(minipo)
         print("The generated xml:")
         print(bytes(tmx))
@@ -136,60 +139,61 @@ msgstr "Drie"
 
     def test_nonascii(self):
         """Tests that non-ascii conversion works."""
-        minipo = u'''msgid "Bézier curve"
+        minipo = """msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
+"""
         tmx = self.po2tmx(minipo)
         print(bytes(tmx))
-        assert tmx.translate(u"Bézier curve") == u"Bézier-kurwe"
+        assert tmx.translate("Bézier curve") == "Bézier-kurwe"
 
     def test_nonecomments(self):
         """Tests that none comments are imported."""
-        minipo = u'''#My comment rules
+        minipo = """#My comment rules
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
+"""
         tmx = self.po2tmx(minipo)
         print(bytes(tmx))
-        unit = tmx.findunits(u"Bézier curve")
+        unit = tmx.findunits("Bézier curve")
         assert len(unit[0].getnotes()) == 0
 
     def test_otherscomments(self):
         """Tests that others comments are imported."""
-        minipo = u'''#My comment rules
+        minipo = """#My comment rules
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        tmx = self.po2tmx(minipo, comment='others')
+"""
+        tmx = self.po2tmx(minipo, comment="others")
         print(bytes(tmx))
-        unit = tmx.findunits(u"Bézier curve")
-        assert unit[0].getnotes() == u"My comment rules"
+        unit = tmx.findunits("Bézier curve")
+        assert unit[0].getnotes() == "My comment rules"
 
     def test_sourcecomments(self):
         """Tests that source comments are imported."""
-        minipo = u'''#: ../PuzzleFourSided.h:45
+        minipo = """#: ../PuzzleFourSided.h:45
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        tmx = self.po2tmx(minipo, comment='source')
+"""
+        tmx = self.po2tmx(minipo, comment="source")
         print(bytes(tmx))
-        unit = tmx.findunits(u"Bézier curve")
-        assert unit[0].getnotes() == u"../PuzzleFourSided.h:45"
+        unit = tmx.findunits("Bézier curve")
+        assert unit[0].getnotes() == "../PuzzleFourSided.h:45"
 
     def test_typecomments(self):
         """Tests that others comments are imported."""
-        minipo = u'''#, csharp-format
+        minipo = """#, csharp-format
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
-'''
-        tmx = self.po2tmx(minipo, comment='type')
+"""
+        tmx = self.po2tmx(minipo, comment="type")
         print(bytes(tmx))
-        unit = tmx.findunits(u"Bézier curve")
-        assert unit[0].getnotes() == u"csharp-format"
+        unit = tmx.findunits("Bézier curve")
+        assert unit[0].getnotes() == "csharp-format"
 
 
 class TestPO2TMXCommand(test_convert.TestConvertCommand, TestPO2TMX):
     """Tests running actual po2tmx commands on files"""
+
     convertmodule = po2tmx
 
     def test_help(self, capsys):
